<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>ཉེར་སྤྱོད་ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ལས་ཚབ་ཀྱི་རིགས།</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Port</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>བདམས་ནས་བྲི་བ།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>ལས་ཚབ་སྡེབ་སྒྲིག་བྱས་རྗེས་སུ་འགོ་སློང་ཆས་ཀྱི་གཡས་མཐེབ་འདེམས་བྱང་ལས་“ལས་ཚབ་སྤྱོད་པ་”ཞེས་པ་མཐོང་ཐུབ། དེ་ཉིད་བདམས་རྗེས་ལས་ཚབ་སྤྱོད་ཆོག </translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ཉར་ཚགས། </translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>གོ་མི་ཆོད་པའི་IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>གོ་མི་ཆོད་པའི་མཐུད་ཁ།</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>སྦྲེལ་མཐུད་ཕྲལ་གཅོད། </translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ཉར་ཚགས། </translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>སྦྲེལ་མཐུད་ཕྲལ་གཅོད། </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>ཁྱོད་ཀྱིས་མིག་སྔའི་སྡེབ་སྒྲིག་བསུབ་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>སྐུད་ཡོད་འབྲེལ་མཐུད་%1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>ཚ་གནས།</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>སྐུད་མེད་འབྲེལ་མཐུད་%1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoEའབྲེལ་མཐུད་%1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>VPNགསར་འཛུགས།</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPNརིགས།</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>ཕྱིར་འདྲེན།</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>དྲ་རྒྱ། </translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>ཉེར་སྤྱོད་ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>མི་སྒེར་གྱི་ཚ་གནས།</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>དྲ་རྒྱ་ཞིབ་ཕྲ།</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>རྒྱུད་ཁོངས་ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>སྐུད་ཡོད་དྲ་ཁཱ།</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>དྲ་རྒྱའི་སྒྲིག་འགོད་སྣོན་པ།</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>སྐུད་མེད་དྲ་ཁཱ།</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>ཡིབ་དྲ་དང་མཐུད་པ།</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoའབྲེལ་མཐུད་བཟོ་བ།</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPNགྱི་རྣམ་པ།</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPNསྣོན་པ།</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPNནང་འདྲེན།</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ལས་ཚབ་ཀྱི་རིགས།</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>སྡེབ་སྒྲིག་URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IPགནས་ཡུལ།</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>མཐུད་ཁ།</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>ཚ་གནས།</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>ཚ་གནས་སྣོན་པ།</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>མཐུད་ཁ།</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>བྱུང་རིམ།</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>སྔོན་འདེམས་DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>བུ་དྲ་ཡིབ་ཨང་།</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>སྔོན་སྦྱོར།</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>མྱུར་ཚད།</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>གོ་མི་ཆོད་པའི་DNSགནས་ཡུལ།</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>ཨེ་ཐེར་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>སྒྲིག་ཆས་དམིགས་འཛུགས་མི་བྱེད།</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>སྒྲིག་ཆས་MACཡི་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>འདྲ་བསྐྱེད་MACཡི་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>རང་སྒྲུབ་MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>ཀུན་སྤྱོད།</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>ཀུན་སྤྱོད།</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>མིང་ཡོད་པ།</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>རང་མཐུད།</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>ཚ་གནས།</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>སྒྲིག་འགོད་སྣོན་པ།</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>ཚ་གནས་སྣོན་པ།</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IPགནས་ཡུལ་བསྐྱར་ཟློས།</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>གོ་མི་ཆོད་པའི་IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>གོ་མི་ཆོད་པའི་བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>དྲ་སྒོ་གཅིག་རང་ལ་ཆོག་མཆན་ཡོད།</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>IPགནས་ཡུལ་བསྐྱར་ཟློས།</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>གོ་མི་ཆོད་པའི་IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>དྲ་སྒོ་གཅིག་རང་ལ་ཆོག་མཆན་ཡོད།</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>སྔོན་སྦྱོར།</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ལག་ཐབས།</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>སྣང་མེད་གཏོང་།</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>བལྟོས་བཅས་ཀྱི་དྲ་རྒྱའི་ཐོག་སྤྱོད་པའི་ཐོན་ཁུངས།</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>བྱ་ཐབས།</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>སྔོན་སྦྱོར།</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>གོ་མི་ཆོད་པའི་IPགནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>གོ་མི་ཆོད་པའི་བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>དྲ་རྒྱ། </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>བྱ་ཐབས།</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་བཞིན།</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ལག་ཐབས།</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>སྣང་མེད་གཏོང་།</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>དྲ་རྒྱ་ཞིབ་ཕྲ།</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>རྒྱུད་ཁོངས་ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>ཉེར་སྤྱོད་ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>དྲ་རྒྱ་ཞིབ་ཕྲ།</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>དྲ་བ། </translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>ལག་ཐབས།</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>དྲ་རྒྱའི་དོ་དམ་བྱེད་ཆས་སྤྱད་དེ་སྡེབ་སྒྲིག་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>མི་སྒེར་གྱི་ཚ་གནས།</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>ཨང་གནོན།</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Service</source>
        <translation>ཞབས་ཞུ།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2ར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSDགཞི་གྲངས་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflateགཞི་གྲངས་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCPསྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>གྲོས་མཐུན་གྱི་ཡིག་དུམ་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>གནས་ཡུལ་/ཚོད་འཛིན་གྱི་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>བྲག་ཅའི་ཁུག་མ་PPPསྐུར་བ།</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPEསྤྱད་དེ་ཚེག་ནས་ཚེག་བར་གསང་སྡོམ་བྱེད་པ།</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE128སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>རྣམ་པ་ཡོད་པའི་MPPEསྤྱོད་པ།</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoའབྲེལ་མཐུད་བཟོ་བ།</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>རྒྱུད་ཁོངས་ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>ཉར་ཚགས། </translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ལས་ཚབ་ཀྱི་རིགས།</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>ལག་ཐབས།</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>བདམས་ནས་བྲི་བ།</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>ལས་ཚབ་HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>ལས་ཚབ་HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>ལས་ཚབ་FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>ལས་ཚབ་SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>གོང་གི་རྩིས་འཁོར་ཨ་མ་དང་ཁོངས་ཀྱི་ལས་ཚབ་སྡེབ་སྒྲིག་སྣང་མེད་དུ་གཏོང་།</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>སྡེབ་སྒྲིག་URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>བདེ་འཇགས།</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>ཕུག་ལམ་TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>སྲུང་སྐྱོང་ཡོད་པའི་EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>སྤྱོད་མཁན་འདིར་གསང་ཨང་ཉར་གསོག་བྱེད་རོགས།</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>སྤྱོད་མཁན་གསང་ཨང་ཆ་ཚང་ཉར་གསོག་བྱེད།</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>རྟག་ཏུ་འདྲི་རྩད་བྱེད།</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>མིང་མི་འགོད་པ།</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>ར་སྤྲོད་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>གཉིས་ཀ་ཡོད་པ།</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>པར་གཞི་0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>པར་གཞི་1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAPར་སྤྲོད།</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>ཐོབ་ཐང་།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>གསང་ཨང་གདམ་གསེས།</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>སྒེར་ལྡེ།</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CAདཔང་ཡིག</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>སྤྱོད་མཁན་དཔང་ཡིག</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>མིང་མེད་ཐོབ་ཐང་།</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>PACརང་འགུལ་སྡེབ་སྒྲིག</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PACཡིག་ཆ།</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>ནང་ལོགས་ར་སྤྲོད།</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAPཔར་གཞི།</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>སྒེར་ལྡེའི་གསང་ཨང་།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>གསང་ཨང་ནུས་མེད།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད།</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>སྒེར་གྱི་པར་གཞི་WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3མི་སྒེར་གྱི་པར་གཞི།</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>བདེ་འཇགས།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Key</source>
        <translation>གསང་ལྡེ།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>བདེ་འཇགས།</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>གསང་ཨང་ནུས་མེད།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད།</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>སྒེར་གྱི་པར་གཞི་WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>ཁེ་ལས་ཀྱི་པར་གཞི་WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3མི་སྒེར་གྱི་པར་གཞི།</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>མཉམ་སྤྱོད་གསང་ལྡེ།</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>རྒྱ་མེད་རྒྱུད་ཁོངས།</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>བདེ་འཇགས།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>བདེ་འཇགས་ར་སྤྲོད་རིགས་གྲས།</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>གསང་ལྡེ།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPNམཐོ་རིམ་གདམ་ཚན།</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>རང་སྒྲུབ་དྲ་སྒོའི་མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>དྲ་སྒོའི་མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>རང་སྒྲུབ་ཀྱིས་བར་གསེང་ཡང་བསྐྱར་གྲོས་མཐུན་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>བར་གསེང་ཡང་བསྐྱར་གྲོས་མཐུན་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZOསྤྱད་དེ་སྡུད་སྒྲིལ་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCPསྤྱད་དེ་འབྲེལ་མཐུད་པ།</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>སྒྲིག་ཆས་TAPསྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>རང་སྒྲུབ་བརྒྱུད་གཏོང་སྡེ་ཚན་ཆེ་ཤོས། (MTU) </translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>རང་སྒྲུབ་UDPགཞི་གྲངས་ཀྱི་དུམ་བུའི་རིང་ཚད།</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDPགཞི་གྲངས་ཀྱི་དུམ་བུའི་རིང་ཚད།</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>ཚད་བཀག་ཕུག་ལམ་TCPཡི་དུམ་བུ་རིང་ཤོས་ཀྱི་རིང་ཚད།(MSS)</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>སྐབས་བསྟུན་རྒྱང་སྦྲེལ་རྩིས་འཁོར་ཨ་མ།</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPNམཐོ་རིམ་གདམ་ཚན།</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>སི་ཁོ་（སོར་བཞག）</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>དྲ་ངོས།</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>བདེ་འཇགས།（སོར་བཞག）</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>ཞན་པ།</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད།</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-Tསྤྱོད་ཆོག་ཚེ་（སོར་བཞག）</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>རྟག་ཏུ་NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>སི་ཁོ་UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2（སོར་བཞག）</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>ཞབས་ཞུ་འཕྲུལ་ཆས་（སོར་བཞག）</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>ཁོངས།</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>འདོན་སྤྲོད་ཚོང་པ།</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>པར་གཞི།</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>གསང་སྡོམ།</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NATརེ་རེ་བཞིན་འདྲི་བ།</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DHཚོ།</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>མདུན་ཕྱོགས་གསང་སྲུང་།</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>རང་སའི་མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>འགྱུར་མེད་མཐུད་ཁ་དཔྱད་འཇལ་བྱ་མི་ཆོག </translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsecསྤྱོད་པ།</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>ཚོ་མིང་།</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ཚོའི་ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>སྔོན་འགྲོའི་མཉམ་སྤྱོད་གསང་ལྡེ།</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>གསང་ལྡེ་1 བརྗེ་བའི་གྲོས་མཐུན།</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>བདེ་འཇགས་2གཏུམ་པའི་གྲོས་མཐུན།</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CAདཔང་ཡིག</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>ལས་ཚབ།</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>སི་ཁོའི་བདེ་འཇགས་ཅོག་ངོས་ཀྱི་ཤིང་རྟ་སྤྱོད་ཆོག </translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSDའཁྲབ་གཞུང་།</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>སྤྱོད་མཁན་དཔང་ཡིག</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>སྒེར་ལྡེ།</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>གསང་ལྡེའི་བཀའ་ལ་FSIDསྤྱོད་པ།</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>དཔང་ཡིག（TLS）</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>དཔང་ཡིག་དང་གསང་ཨང་།（TLS）</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>འཇགས་རྣམ་གསང་ཨང་།</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ཉར་ཚགས་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>རྟག་ཏུ་འདྲི་བ།</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>རེ་བ་མེད།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>ར་སྤྲོད་ཀྱི་རིགས།</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CAདཔང་ཡིག</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>སྤྱོད་མཁན་དཔང་ཡིག</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>སྒེར་ལྡེ།</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>གསང་ཨང་གདམ་གསེས།</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>སྒེར་ལྡེའི་གསང་ཨང་།</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>རང་སྒྲུབ་གསང་ལྡེའི་ཁ་ཕྱོགས།</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>གསང་ལྡེའི་ཁ་ཕྱོགས།</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>རྒྱང་སྦྲེལ་IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>རང་སའི་IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>ཚང་མ་སྤྱོད་ཆོག（སོར་བཞག）</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>གནས་40（བདེ་འཇགས།）</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>གནས་128（བདེ་འཇགས།）</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAPར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2ར་སྤྲོད་ཟློག་པ།</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSDགཞི་གྲངས་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Deflateགཞི་གྲངས་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCPསྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>གྲོས་མཐུན་གྱི་ཡིག་དུམ་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>གནས་ཡུལ་/ཚོད་འཛིན་གྱི་སྡུད་སྒྲིལ་མེད།</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>བྲག་ཅའི་ཁུག་མ་PPPསྐུར་བ།</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPEསྤྱད་དེ་ཚེག་ནས་ཚེག་བར་གསང་སྡོམ་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>བདེ་འཇགས།</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>རྣམ་པ་ཡོད་པའི་MPPEསྤྱོད་པ།</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPNགྱི་རྣམ་པ།</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPNསྣོན་པ།</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPNནང་འདྲེན།</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>ནང་འདྲེན་ནོར་སྐྱོན།</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>ཡིག་ཆ་ནང་འདྲེན་ནོར་སྐྱོན།</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>གཏན་ཁེལ།</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPNལས་ཚབ།</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>རེ་བ་མེད།</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>ལས་ཚབ་ཀྱི་རིགས།</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>ཞབས་ཞུ་འཕྲུལ་ཆས་ཀྱི་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Port</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>ཕམ་ཚེ་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CAཡིག་ཆ།</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>དཔང་ཡིག་གི་ཉེན་བརྡ་སྣང་མེད་དུ་གཏོང་།</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLSསྤྱད་དེ་རྩིས་འཁོར་ཨ་མའི་མིང་རྒྱ་སྐྱེད།</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPNབདེ་འཇགས།</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>སོར་བཞག</translation>
    </message>
    <message>
        <source>None</source>
        <translation>མེད།</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>གསང་སྡོམ།</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMACར་སྤྲོད།</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ཉར་ཚགས་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>རྟག་ཏུ་འདྲི་བ།</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>རེ་བ་མེད།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>གསང་ཨང་གདམ་གསེས།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NTཁོངས།</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPNལས་ཚབ།</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>ཞབས་ཞུ་འཕྲུལ་ཆས་ཀྱི་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>སྒེར་ལྡེ།</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSHལས་ཚབ།</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>རིག་ལྡན་ཁཱ།</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>སྔོན་འགྲོའི་མཉམ་སྤྱོད་གསང་ལྡེ།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CAདཔང་ཡིག</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>ར་སྤྲོད་ཀྱི་རིགས།</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>སྤྱོད་མཁན་དཔང་ཡིག</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>ནང་ལོགས་ཀྱི་IPགནས་ཡུལ་རེ་ཞུ་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>བཙན་ཤེད་ཀྱིས་UDPསྤྱད་དེ་ཐུམས།</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IPསྤྱད་དེ་སྡུད་སྒྲིལ་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>རང་སྒྲབ་གསང་སྡོམ་ཇུས་གཞི་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS ར་སྤྲོད།</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>སོར་བཞག</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>མཁོ་མཁན་ཕྱོགས།</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>ཞབས་ཞུ་འཕྲུལ་ཆས། </translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>བརྗོད་གཞི་ཟླ་སྒྲིག</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>རྒྱང་སྦྲེལ་དཔང་ཡིག་གི་རིགས།</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>གསང་ལྡེའི་ཡིག་ཆ།</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>རང་སྒྲུབ་གསང་ལྡེའི་ཁ་ཕྱོགས།</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>གསང་ལྡེའི་ཁ་ཕྱོགས།</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>གོ་མི་ཆོད་པའི་དྲ་སྒོ་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>ཉར་ཚགས་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>རྟག་ཏུ་འདྲི་བ།</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>རེ་བ་མེད།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་། </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>གསང་ཨང་གདམ་གསེས།</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>གསང་ཨང་། </translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>ཚོ་མིང་།</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>ཚོ་ཆུང་གི་གསང་ཨང་།</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>མཉམ་བསྲེས་ར་སྤྲོད་སྤྱོད་པ།</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CAཡིག་ཆ།</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>སྔོན་ལ་དྲ་སྐུད་མཐུད་རོགས།</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>སྐུད་ཡོད་དྲ་ཁཱ།</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>དྲ་རྒྱའི་སྒྲིག་འགོད་སྣོན་པ།</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>སྒྲིག་འགོད་འདེམས་པ།</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>སྐུད་མེད་དྲ་ཁཱ།</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>ཚ་གནས་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>སྐུད་མེད་དྲ་རྒྱའི་རྩོལ་ནུས་དང་མཐུད་ནས་བེད་སྤྱོད་གཏོང་དགོས་ཚེ། སྔོན་ལ་ཚ་གནས་མཉམ་སྤྱོད་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>ཡིབ་དྲ་དང་མཐུད་པ།</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>སྒྲིག་ཆས་དམིགས་འཛུགས་མི་བྱེད།</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>སྒྲིག་ཆས་MACཡི་གནས་ཡུལ།</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>རང་སྒྲུབ་MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>ཚ་གནས།</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>གྲོས་མཐུན།</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>བདེ་འཇགས་རིགས།</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>དྲ་རྒྱའི་རྒྱུ་ལམ།</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>བྱུང་རིམ།</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>མཐུད་ཁ།</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>བུ་དྲ་ཡིབ་ཨང་།</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>དྲ་སྒོ།</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>སྔོན་འདེམས་DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>སྔོན་སྦྱོར།</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>མྱུར་ཚད།</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>སྒྲིག་ཆས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>སྦྲེལ་མེད་པ། </translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>ར་སྤྲོད་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation> IP གནས་ཡུལ་འཚོལ་བཞིན་པ།</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>སྦྲེལ་ཟིན། </translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>བཅད་ཟིན།</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>ཕམ་པ།</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>གནས་ཡུལ་འཚོལ་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>སྐུད་ཡོད་དྲ་རྒྱ་%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>སྐུད་མེད་དྲ་རྒྱ་%1</translation>
    </message>
</context>
</TS>